multivitamin.applications.images.detectors package
==================================================

Submodules
----------

multivitamin.applications.images.detectors.mm\_detector module
--------------------------------------------------------------

.. automodule:: multivitamin.applications.images.detectors.mm_detector
   :members:
   :undoc-members:
   :show-inheritance:

multivitamin.applications.images.detectors.ssd\_detector module
---------------------------------------------------------------

.. automodule:: multivitamin.applications.images.detectors.ssd_detector
   :members:
   :undoc-members:
   :show-inheritance:

multivitamin.applications.images.detectors.tf\_detector module
--------------------------------------------------------------

.. automodule:: multivitamin.applications.images.detectors.tf_detector
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: multivitamin.applications.images.detectors
   :members:
   :undoc-members:
   :show-inheritance:
